==> certmanager-model-v1beta1-5.10.1-sources.jar: io/fabric8/certmanager/api/model/v1beta1/CertificateSpecBuilder.java <==
package io.fabric8.certmanager.api.model.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CertificateSpecBuilder extends io.fabric8.certmanager.api.model.v1beta1.CertificateSpecFluentImpl<io.fabric8.certmanager.api.model.v1beta1.CertificateSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.v1beta1.CertificateSpec,io.fabric8.certmanager.api.model.v1beta1.CertificateSpecBuilder>{
  public CertificateSpecBuilder() {
    this(false);
  }
  public CertificateSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new CertificateSpec(), validationEnabled);
  }
  public CertificateSpecBuilder(io.fabric8.certmanager.api.model.v1beta1.CertificateSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateSpecBuilder(io.fabric8.certmanager.api.model.v1beta1.CertificateSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CertificateSpec(), validationEnabled);
  }
  public CertificateSpecBuilder(io.fabric8.certmanager.api.model.v1beta1.CertificateSpecFluent<?> fluent,io.fabric8.certmanager.api.model.v1beta1.CertificateSpec instance) {
    this(fluent, instance, false);
  }
  public CertificateSpecBuilder(io.fabric8.certmanager.api.model.v1beta1.CertificateSpecFluent<?> fluent,io.fabric8.certmanager.api.model.v1beta1.CertificateSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCommonName(instance.getCommonName()); 
    fluent.withDnsNames(instance.getDnsNames()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withEmailSANs(instance.getEmailSANs()); 
    fluent.withEncodeUsagesInRequest(instance.getEncodeUsagesInRequest()); 
    fluent.withIpAddresses(instance.getIpAddresses()); 
    fluent.withIsCA(instance.getIsCA()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withKeystores(instance.getKeystores()); 
    fluent.withPrivateKey(instance.getPrivateKey()); 
    fluent.withRenewBefore(instance.getRenewBefore()); 
    fluent.withSecretName(instance.getSecretName()); 
    fluent.withSubject(instance.getSubject()); 
    fluent.withUriSANs(instance.getUriSANs()); 
    fluent.withUsages(instance.getUsages()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateSpecBuilder(io.fabric8.certmanager.api.model.v1beta1.CertificateSpec instance) {
    this(instance,false);
  }
  public CertificateSpecBuilder(io.fabric8.certmanager.api.model.v1beta1.CertificateSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCommonName(instance.getCommonName()); 
    this.withDnsNames(instance.getDnsNames()); 
    this.withDuration(instance.getDuration()); 
    this.withEmailSANs(instance.getEmailSANs()); 
    this.withEncodeUsagesInRequest(instance.getEncodeUsagesInRequest()); 
    this.withIpAddresses(instance.getIpAddresses()); 
    this.withIsCA(instance.getIsCA()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withKeystores(instance.getKeystores()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withRenewBefore(instance.getRenewBefore()); 
    this.withSecretName(instance.getSecretName()); 
    this.withSubject(instance.getSubject()); 
    this.withUriSANs(instance.getUriSANs()); 
    this.withUsages(instance.getUsages()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.v1beta1.CertificateSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.v1beta1.CertificateSpec build() {
    CertificateSpec buildable = new CertificateSpec(fluent.getCommonName(),fluent.getDnsNames(),fluent.getDuration(),fluent.getEmailSANs(),fluent.getEncodeUsagesInRequest(),fluent.getIpAddresses(),fluent.getIsCA(),fluent.getIssuerRef(),fluent.getKeystores(),fluent.getPrivateKey(),fluent.getRenewBefore(),fluent.getSecretName(),fluent.getSubject(),fluent.getUriSANs(),fluent.getUsages());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificateSpecBuilder that = (CertificateSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1beta1-6.0.0-sources.jar: io/fabric8/certmanager/api/model/v1beta1/CertificateSpecBuilder.java <==
package io.fabric8.certmanager.api.model.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateSpecBuilder extends CertificateSpecFluentImpl<CertificateSpecBuilder> implements VisitableBuilder<CertificateSpec,CertificateSpecBuilder>{
  public CertificateSpecBuilder() {
    this(false);
  }
  public CertificateSpecBuilder(Boolean validationEnabled) {
    this(new CertificateSpec(), validationEnabled);
  }
  public CertificateSpecBuilder(CertificateSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateSpecBuilder(CertificateSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateSpec(), validationEnabled);
  }
  public CertificateSpecBuilder(CertificateSpecFluent<?> fluent,CertificateSpec instance) {
    this(fluent, instance, false);
  }
  public CertificateSpecBuilder(CertificateSpecFluent<?> fluent,CertificateSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCommonName(instance.getCommonName()); 
    fluent.withDnsNames(instance.getDnsNames()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withEmailSANs(instance.getEmailSANs()); 
    fluent.withEncodeUsagesInRequest(instance.getEncodeUsagesInRequest()); 
    fluent.withIpAddresses(instance.getIpAddresses()); 
    fluent.withIsCA(instance.getIsCA()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withKeystores(instance.getKeystores()); 
    fluent.withPrivateKey(instance.getPrivateKey()); 
    fluent.withRenewBefore(instance.getRenewBefore()); 
    fluent.withSecretName(instance.getSecretName()); 
    fluent.withSubject(instance.getSubject()); 
    fluent.withUriSANs(instance.getUriSANs()); 
    fluent.withUsages(instance.getUsages()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateSpecBuilder(CertificateSpec instance) {
    this(instance,false);
  }
  public CertificateSpecBuilder(CertificateSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCommonName(instance.getCommonName()); 
    this.withDnsNames(instance.getDnsNames()); 
    this.withDuration(instance.getDuration()); 
    this.withEmailSANs(instance.getEmailSANs()); 
    this.withEncodeUsagesInRequest(instance.getEncodeUsagesInRequest()); 
    this.withIpAddresses(instance.getIpAddresses()); 
    this.withIsCA(instance.getIsCA()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withKeystores(instance.getKeystores()); 
    this.withPrivateKey(instance.getPrivateKey()); 
    this.withRenewBefore(instance.getRenewBefore()); 
    this.withSecretName(instance.getSecretName()); 
    this.withSubject(instance.getSubject()); 
    this.withUriSANs(instance.getUriSANs()); 
    this.withUsages(instance.getUsages()); 
    this.validationEnabled = validationEnabled; 
  }
  CertificateSpecFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateSpec build() {
    CertificateSpec buildable = new CertificateSpec(fluent.getCommonName(),fluent.getDnsNames(),fluent.getDuration(),fluent.getEmailSANs(),fluent.getEncodeUsagesInRequest(),fluent.getIpAddresses(),fluent.getIsCA(),fluent.getIssuerRef(),fluent.getKeystores(),fluent.getPrivateKey(),fluent.getRenewBefore(),fluent.getSecretName(),fluent.getSubject(),fluent.getUriSANs(),fluent.getUsages());
    return buildable;
  }
  
}
